@@ -2,9 +2,10 @@
 
 echo "[A1] Single-Page Template Layout, Black+White, Full Processing."
 
-. tests/prologue.sh
+set -e
+set -x
 
 rm -f tests/resultsA1.pbm
-$UNPAPER -v --overwrite tests/imgsrc001.pbm tests/resultsA1.pbm
+./unpaper -v tests/imgsrc001.pbm tests/resultsA1.pbm
 
 [ -f tests/resultsA1.pbm ]
