@@ -2,9 +2,10 @@
 
 echo "[D3] Stretch to sheet size."
 
-. tests/prologue.sh
+set -e
+set -x
 
 rm -f tests/resultsD3.ppm
-$UNPAPER -v --overwrite -n --stretch 20cm,10cm tests/imgsrc003.ppm tests/resultsD3.ppm
+./unpaper -v -n --stretch 20cm,10cm tests/imgsrc003.ppm tests/resultsD3.ppm
 
 [ -f tests/resultsD3.ppm ]
